package com.landray.kmss.sys.attachment.integrate.wps.authen;

import java.io.Writer;
import java.io.PrintWriter;
import java.io.FileWriter;
import java.io.File;
import com.alibaba.fastjson.JSONObject;
import com.landray.kmss.sys.attachment.integrate.wps.model.ThirdWpsOfficeTokenInfo;
import org.slf4j.LoggerFactory;
import org.slf4j.Logger;

public abstract class WpsOfficeTokenGenerator
{
    public static final String COOKIE_DOMAIN = "cookie.domain";
    public static final String COOKIE_MAXAGE = "cookie.maxAge";
    public static final String COOKIE_NAME = "cookie.name";
    public static final String INSTANCE_CLASS = "instance.class";
    private static Logger logger;
    private static WpsOfficeTokenGenerator generator;
    private String cookieName;
    private String domain;
    private String[] domains;
    private long maxAge;
    
    static {
        WpsOfficeTokenGenerator.logger = LoggerFactory.getLogger(WpsOfficeTokenGenerator.class);
    }
    
    public WpsOfficeTokenGenerator() {
        this.maxAge = 43200L;
    }
    
    public static WpsOfficeTokenGenerator getInstance() throws IllegalAccessError {
        if (WpsOfficeTokenGenerator.generator == null) {
            WpsOfficeTokenGenerator.generator = new WpsOfficeLRTokenGenerator();
        }
        return WpsOfficeTokenGenerator.generator;
    }
    
    public static boolean isInitialized() {
        return WpsOfficeTokenGenerator.generator != null;
    }
    
    public static WpsOfficeTokenGenerator loadTokenInfo(final String json) throws Exception {
        final ThirdWpsOfficeTokenInfo info = (ThirdWpsOfficeTokenInfo)JSONObject.parseObject(json, (Class)ThirdWpsOfficeTokenInfo.class);
        WpsOfficeTokenGenerator.generator.init(info.getSecurityKeyPublic(), info.getSecurityKeyPrivate());
        return WpsOfficeTokenGenerator.generator;
    }
    
    protected abstract void init(final String p0, final String p1) throws Exception;
    
    public String getCookieName() {
        return this.cookieName;
    }
    
    public void setCookieName(final String cookieName) {
        this.cookieName = cookieName;
    }
    
    public String getDomain() {
        return this.domain;
    }
    
    public void setDomain(final String domain) {
        this.domain = domain;
    }
    
    public long getMaxAge() {
        return this.maxAge;
    }
    
    public void setMaxAge(final long maxAge) {
        this.maxAge = maxAge;
    }
    
    public abstract WpsOfficeToken generateTokenByTokenString(final String p0);
    
    public abstract WpsOfficeToken generateTokenByUserName(final String p0);
    
    public void storeToKeyFile(final String filename) throws Exception {
        String instance = this.getClass().getName();
        final int index = instance.lastIndexOf(46);
        instance = instance.substring(index + 1);
        final StringBuffer sb = new StringBuffer();
        sb.append("instance.class").append("=").append(instance).append("\r\n");
        sb.append("cookie.name").append("=").append(this.cookieName).append("\r\n");
        sb.append("cookie.maxAge").append("=").append(this.maxAge).append("\r\n");
        sb.append("cookie.domain").append("=").append(this.domain).append("\r\n");
        sb.append(this.getKeyFileString());
        final File keyFile = new File(filename);
        final PrintWriter writer = new PrintWriter(new FileWriter(keyFile));
        writer.print(sb);
        writer.close();
    }
    
    protected abstract String getKeyFileString();
    
    public String getSuitedDomain(final String appurl) {
        if (this.domains == null) {
            return null;
        }
        String[] domains;
        for (int length = (domains = this.domains).length, i = 0; i < length; ++i) {
            final String domain = domains[i];
            if (appurl.endsWith(domain.trim())) {
                return domain.trim();
            }
        }
        return null;
    }
    
    public void setDomains(final String[] domains) {
        this.domains = domains;
    }
    
    public String[] getDomains() {
        return this.domains;
    }
}
